Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(127)

Unified Diff: net/base/mime_util.h

Issue 254983006: Fix: Adding list of supported codecs for MP4 containers (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Changing mp4a.40 to mp4a.40.2 Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/base/mime_util.h
diff --git a/net/base/mime_util.h b/net/base/mime_util.h
index 6c943a7f7da83dc1f1e021c6db4578bfe7188621..3bb1f8932aede52afef9a2518b65f32e96ed55ca 100644
--- a/net/base/mime_util.h
+++ b/net/base/mime_util.h
@@ -94,12 +94,16 @@ NET_EXPORT void ParseCodecString(const std::string& codecs,
// certain subset of codecs.
NET_EXPORT bool IsStrictMediaMimeType(const std::string& mime_type);
+enum SupportsType { IsNotSupported, IsSupported, MayBeSupported };
Ryan Sleevi 2014/06/10 19:15:43 1) Have you run git cl format on this? 2) Document
amogh.bihani 2014/06/11 11:32:41 Done.
+
// Check to see if a particular MIME type is in our list which only supports a
-// certain subset of codecs. Returns true if and only if all codecs are
-// supported for that specific MIME type, false otherwise. If this returns
-// false you will still need to check if the media MIME tpyes and codecs are
-// supported.
-NET_EXPORT bool IsSupportedStrictMediaMimeType(
+// certain subset of codecs.
+// * Returns IsSupported if and only if all the codecs are supported for that
+// specific MIME type.
+// * Returns MayBeSupported if codecs paramter is empty or has a profile
Ryan Sleevi 2014/06/10 19:15:43 typo: paramter
amogh.bihani 2014/06/11 11:32:41 rectified.
+// parameter which can't be decided whether it is supported or not.
+// * Returns IsNotSupported if none of the aforementioned conditions are met.
Ryan Sleevi 2014/06/10 19:15:43 With the above comment for SupportsType, let's bui
amogh.bihani 2014/06/11 11:32:41 Done.
+NET_EXPORT SupportsType IsSupportedStrictMediaMimeType(
const std::string& mime_type,
const std::vector<std::string>& codecs);

Powered by Google App Engine
This is Rietveld 408576698